@@ -5,6 +5,10 @@
 chrome.storage.onChanged.addListener(function(changes, namespace) {
   if (namespace === 'session' && changes.notify?.newValue === 'yes') {
     chrome.runtime.sendMessage('storage.session.onChanged received');
+  } else if (namespace === 'local' && changes.notify?.newValue === 'yes') {
+    chrome.runtime.sendMessage('storage.local.onChanged received');
+  } else if (namespace === 'sync' && changes.notify?.newValue === 'yes') {
+    chrome.runtime.sendMessage('storage.sync.onChanged received');
   } else {
     chrome.runtime.sendMessage(
         `script received an unexpected event: ${JSON.stringify(changes)}`);
