@@ -3,13 +3,19 @@
 // found in the LICENSE file.
 
 import type {ActorOverlayPageHandlerInterface} from 'chrome://actor-overlay/actor_overlay.mojom-webui.js';
+import {ActorOverlayPageCallbackRouter} from 'chrome://actor-overlay/actor_overlay.mojom-webui.js';
+import type {ActorOverlayPageRemote} from 'chrome://actor-overlay/actor_overlay.mojom-webui.js';
 import {TestBrowserProxy} from 'chrome://webui-test/test_browser_proxy.js';
 
 export class TestActorOverlayBrowserProxy {
+  callbackRouter: ActorOverlayPageCallbackRouter =
+      new ActorOverlayPageCallbackRouter();
   handler: TestActorOverlayPageHandler;
+  remote: ActorOverlayPageRemote;
 
   constructor() {
     this.handler = new TestActorOverlayPageHandler();
+    this.remote = this.callbackRouter.$.bindNewPipeAndPassRemote();
   }
 }
 
