@@ -168,6 +168,11 @@ IN_PROC_BROWSER_TEST_F(CrComponentsMostVisitedTest, DragAndDrop) {
           "runMochaSuite('DragAndDrop');");
 }
 
+IN_PROC_BROWSER_TEST_F(CrComponentsMostVisitedTest, EnterpriseShortcuts) {
+  RunTest("cr_components/most_visited_test.js",
+          "runMochaSuite('EnterpriseShortcuts');");
+}
+
 IN_PROC_BROWSER_TEST_F(CrComponentsMostVisitedTest, Theming) {
   RunTest("cr_components/most_visited_test.js", "runMochaSuite('Theming');");
 }
@@ -197,20 +202,35 @@ IN_PROC_BROWSER_TEST_F(CrComponentsThemeColorPickerTest, ThemeHueSliderDialog) {
           "mocha.run()");
 }
 
-class CrComponentsPrerenderTest : public CrComponentsMostVisitedTest {
+class CrComponentsPreloadingTest : public CrComponentsMostVisitedTest {
  protected:
-  CrComponentsPrerenderTest() {
-    const std::map<std::string, std::string> params = {
-        {"preconnect_start_delay_on_mouse_hover_ms", "0"}};
-    scoped_feature_list_.InitAndEnableFeatureWithParameters(
-        features::kNewTabPageTriggerForPrerender2, params);
+  CrComponentsPreloadingTest() {
+    scoped_feature_list_.InitWithFeaturesAndParameters(
+        {base::test::FeatureRefAndParams(
+             features::kNewTabPageTriggerForPrerender2,
+             {{"preconnect_start_delay_on_mouse_hover_ms", "0"}}),
+         base::test::FeatureRefAndParams(
+             features::kNewTabPageTriggerForPrefetch,
+             {{"prefetch_start_delay_on_mouse_hover_ms", "0"}})},
+        {});
   }
 
  private:
   base::test::ScopedFeatureList scoped_feature_list_;
 };
 
-IN_PROC_BROWSER_TEST_F(CrComponentsPrerenderTest, Prerendering) {
-  RunTest("cr_components/most_visited_test.js",
-          "runMochaSuite('Prerendering');");
+IN_PROC_BROWSER_TEST_F(CrComponentsPreloadingTest, Preloading) {
+  RunTest("cr_components/most_visited_test.js", "runMochaSuite('Preloading');");
+}
+
+class CrComponentsComposeboxTest : public WebUIMochaBrowserTest {
+ protected:
+  CrComponentsComposeboxTest() {
+    set_test_loader_host(chrome::kChromeUINewTabPageHost);
+  }
+};
+
+IN_PROC_BROWSER_TEST_F(CrComponentsComposeboxTest, ContextMenuEntrypoint) {
+  RunTest("cr_components/composebox/context_menu_entrypoint_test.js",
+          "mocha.run()");
 }
