@@ -980,25 +980,6 @@ suite('CookiesCardNavigations', function() {
         page, syncBrowserProxy, testPrivacyGuideBrowserProxy);
   });
 
-  // TODO(crbug.com/370008370): Remove once AlwaysBlock3pcsIncognito launched.
-  test('cookieControlsModeOffNavigatesAway', async function() {
-    loadTimeData.overrideValues({
-      isAlwaysBlock3pcsIncognitoEnabled: false,
-      is3pcdCookieSettingsRedesignEnabled: false,
-    });
-
-    await navigateToStep(PrivacyGuideStep.COOKIES);
-    assertCookiesCardVisible(
-        page, syncBrowserProxy, testPrivacyGuideBrowserProxy);
-
-    // Allowing 3PCs should navigate away from the cookies card.
-    setThirdPartyCookieSetting(page, CookieControlsMode.OFF);
-    await flushTasks();
-    assertCompletionCardVisible(page);
-    // Verify user actions are only emitted for available cards on navigation.
-    assertEquals(0, testMetricsBrowserProxy.getCallCount('recordAction'));
-  });
-
   test('cookiesBlockAllNavigatesAway', async function() {
     await navigateToStep(PrivacyGuideStep.COOKIES);
     assertCookiesCardVisible(
@@ -1012,21 +993,6 @@ suite('CookiesCardNavigations', function() {
     assertEquals(0, testMetricsBrowserProxy.getCallCount('recordAction'));
   });
 
-  // TODO(crbug.com/370008370): Remove once AlwaysBlock3pcsIncognito launched.
-  test(
-      'cookiesCardNotVisibleWhenAlwaysBlock3pcsIncognitoDisabled', function() {
-        loadTimeData.overrideValues({
-          isAlwaysBlock3pcsIncognitoEnabled: false,
-          is3pcdCookieSettingsRedesignEnabled: false,
-        });
-
-        setFirstPartyCookieSetting(page, ContentSetting.DEFAULT);
-        setThirdPartyCookieSetting(page, CookieControlsMode.OFF);
-        setThirdPartyCookieBlockingSetting(
-            page, ThirdPartyCookieBlockingSetting.INCOGNITO_ONLY);
-        assertFalse(shouldShowCookiesCard(page));
-      });
-
   test('hatsInformedOnFinish', async function() {
     await navigateToStep(PrivacyGuideStep.COOKIES);
 
@@ -1386,8 +1352,7 @@ suite('3pcdOff', function() {
     const cookiesRadioGroup =
         page.shadowRoot!
             .querySelector<HTMLElement>('#' + PrivacyGuideStep.COOKIES)!
-            .shadowRoot!.querySelector<HTMLElement>(
-                '#cookiesRadioGroupAlwaysBlock3pcsIncognito');
+            .shadowRoot!.querySelector<HTMLElement>('#cookiesRadioGroup');
     assertTrue(!!cookiesRadioGroup);
     cookiesRadioGroup.dispatchEvent(arrowLeftEvent);
     assertCookiesCardVisible(
@@ -1465,29 +1430,6 @@ suite('3pcdOff', function() {
             actionResult, 'Settings.PrivacyGuide.NextClickSafeBrowsing');
       });
 
-  // TODO(crbug.com/370008370): Remove once AlwaysBlock3pcsIncognito launched.
-  test('safeBrowsingForwardNavigationShouldHideCookies', async function() {
-    loadTimeData.overrideValues({
-      isAlwaysBlock3pcsIncognitoEnabled: false,
-    });
-    setThirdPartyCookieSetting(page, CookieControlsMode.OFF);
-    await navigateToStep(PrivacyGuideStep.SAFE_BROWSING);
-    assertSafeBrowsingCardVisible(
-        page, syncBrowserProxy, testPrivacyGuideBrowserProxy);
-
-    const nextButton =
-        page.shadowRoot!.querySelector<HTMLElement>('#nextButton');
-    assertTrue(!!nextButton);
-    nextButton.click();
-    await flushTasks();
-    assertCompletionCardVisible(page);
-    // Verify user actions are only emitted for available cards on navigation.
-    assertEquals(1, testMetricsBrowserProxy.getCallCount('recordAction'));
-    assertEquals(
-        'Settings.PrivacyGuide.NextClickSafeBrowsing',
-        testMetricsBrowserProxy.getArgs('recordAction')[0]);
-  });
-
   test('cookiesBackNavigationSafeBrowsingOn', async function() {
     await navigateToStep(PrivacyGuideStep.COOKIES);
     assertCookiesCardVisible(
