@@ -4,7 +4,7 @@
 import 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
 
 import type {AppElement} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
-import {BrowserProxy, currentReadHighlightClass, previousReadHighlightClass, ReadAloudHighlighter, SpeechController} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
+import {BrowserProxy, currentReadHighlightClass, getReadAloudModel, previousReadHighlightClass, ReadAloudHighlighter, SpeechController} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
 import {assertEquals} from 'chrome-untrusted://webui-test/chai_assert.js';
 import {microtasksFinished} from 'chrome-untrusted://webui-test/test_util.js';
 
@@ -74,13 +74,15 @@ suite('UpdateContentSelectionWithHighlights', () => {
     let i = 0;
     while (textNodeIds[i]! !== id) {
       fakeTree.highlightNode(textNodeIds[i]!);
-      highlighter.highlightCurrentGranularity([textNodeIds[i]!], false, true);
+      highlighter.highlightCurrentGranularity(
+          getReadAloudModel().getCurrentTextSegments(), false, true);
       i++;
     }
 
     // highlight given node
     fakeTree.highlightNode(id);
-    highlighter.highlightCurrentGranularity([id], false, true);
+    highlighter.highlightCurrentGranularity(
+        getReadAloudModel().getCurrentTextSegments(), false, true);
     return microtasksFinished();
   }
 
@@ -90,17 +92,15 @@ suite('UpdateContentSelectionWithHighlights', () => {
     let i = 0;
     while (fromId !== textNodeIds[i]!) {
       fakeTree.highlightNode(textNodeIds[i]!);
-      highlighter.highlightCurrentGranularity([textNodeIds[i]!], false, true);
+      highlighter.highlightCurrentGranularity(
+          getReadAloudModel().getCurrentTextSegments(), false, true);
       i++;
     }
 
     // highlight given nodes
     fakeTree.setReadingHighlight(fromId, fromOffset, toId, toOffset);
-    const nodeIds = [fromId];
-    if (toId !== fromId) {
-      nodeIds.push(toId);
-    }
-    highlighter.highlightCurrentGranularity(nodeIds, false, true);
+    highlighter.highlightCurrentGranularity(
+        getReadAloudModel().getCurrentTextSegments(), false, true);
     return microtasksFinished();
   }
 
